<!doctype html>
<html>
   <head>
   <title>Simple Transactional Email</title>
   <style>
      {% block style %}
      {% endblock %}
   </style>
   </head>
   <body>
      <span class="preheader">{% block preview %}{% endblock %}</span>
      {% block content %}
      {% endblock %}
   </body>
</html>
