{% extends "base.html.j2" %}

{% block style %}
   {% include "table-style.css" %}
{% endblock %}

{% block content %}
<table role="presentation" border="0" cellpadding="0" cellspacing="0" class="body">
   <tr>
      <td>&nbsp;</td>
      <td class="container">
         <div class="content">
         <!-- START CENTERED WHITE CONTAINER -->
            <table role="presentation" class="main">
               <!-- START MAIN CONTENT AREA -->
               <tr>
                  <td class="wrapper">
                     <table role="presentation" border="0" cellpadding="0" cellspacing="0">
                        <tr>
                           <td>

                              {% if title %}
                                 <h1>{{ title }}</h1>
                              {% endif %}

                              {% block inner_content %}
                              {% endblock %}

                              {% if sender %}
                              <p class="sender-info">
                              Best regards,<br><span class="sender-name">{{ sender }}</span>
                              </p>
                              {% endif %}

                           </td>
                        </tr>
                     </table>
                  </td>
               </tr>
               <!-- END MAIN CONTENT AREA -->
            </table>
            <!-- END CENTERED WHITE CONTAINER -->

            <!-- START FOOTER -->
            <div class="footer">
               <table role="presentation" border="0" cellpadding="0" cellspacing="0">
                  <tr>
                     <td class="content-block">
                     {% if address %}
                        <span class="apple-link">{{ address }}</span>
                     {% endif %}
                     {% if unsub_link %}
                        <br> Don't like these emails? <a href="{{ unsub_link }}">Unsubscribe</a>.
                     {% endif %}
                     </td>
                  </tr>
               </table>
            </div>
         <!-- END FOOTER -->
         </div>
      </td>
      <td>&nbsp;</td>
   </tr>
</table>
{% endblock %}
